@@ -25,14 +25,14 @@ class EnviarPedido(Enviar):
             notification_url=notification_url,
             external_reference=self.pedido.numero,
             payer=Payer(
-                name=self.pedido.cliente.nome.split()[0],
-                surname=self.pedido.cliente.nome.split()[-1],
+                name=unicode(self.pedido.cliente.nome.split()[0]),
+                surname=unicode(self.pedido.cliente.nome.split()[-1]),
                 email=self.pedido.cliente.email,
                 date_created=self.formatador.formata_data(self.pedido.cliente.data_criacao, iso=True),
                 phone=self.telefone,
                 identification=self.identificacao,
                 address=PayerAddress(
-                    street_name=self.pedido.cliente.endereco.endereco,
+                    street_name=unicode(self.pedido.cliente.endereco.endereco),
                     street_number=self.pedido.cliente.endereco.numero,
                     zip_code=self.pedido.cliente.endereco.cep,
                 )
@@ -44,9 +44,9 @@ class EnviarPedido(Enviar):
             ),
             shipments=Shipments(
                 receiver_address=ReceiverAddress(
-                    street_name=self.pedido.endereco_entrega.endereco,
+                    street_name=unicode(self.pedido.endereco_entrega.endereco),
                     street_number=self.pedido.endereco_entrega.numero,
-                    apartment=self.pedido.endereco_entrega.complemento,
+                    apartment=unicode(self.pedido.endereco_entrega.complemento),
                     zip_code=self.pedido.endereco_entrega.cep,
                 )
             ),
@@ -86,8 +86,8 @@ class EnviarPedido(Enviar):
     def items(self):
         items = [
             Item(
-                id=item.sku,
-                title=item.nome,
+                id=unicode(item.sku),
+                title=unicode(item.nome),
                 currency_id="BRL",
                 unit_price=self.formatador.formata_decimal(item.preco_venda, como_float=True),
                 quantity=self.formatador.formata_decimal(item.quantidade, como_float=True),
